"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeRemoveCmd = void 0;
const package_reference_1 = require("../domain/package-reference");
const result_codes_1 = require("./result-codes");
const error_logging_1 = require("./error-logging");
/**
 * Makes a {@link RemoveCmd} function.
 */
function makeRemoveCmd(parseEnv, removePackages, log) {
    return async (pkgs, options) => {
        // parse env
        const envResult = await parseEnv(options);
        if (envResult.isErr()) {
            (0, error_logging_1.notifyEnvParsingFailed)(log, envResult.error);
            return result_codes_1.ResultCodes.Error;
        }
        const env = envResult.value;
        const removeResult = await removePackages(env.cwd, pkgs).promise;
        if (removeResult.isErr()) {
            (0, error_logging_1.notifyPackageRemoveFailed)(log, removeResult.error);
            return result_codes_1.ResultCodes.Error;
        }
        const removedPackages = removeResult.value;
        removedPackages.forEach((removedPackage) => {
            log.notice("", `Removed "${(0, package_reference_1.makePackageReference)(removedPackage.name, removedPackage.version)}".`);
        });
        // print manifest notice
        log.notice("", "please open Unity project to apply changes");
        return result_codes_1.ResultCodes.Ok;
    };
}
exports.makeRemoveCmd = makeRemoveCmd;
//# sourceMappingURL=cmd-remove.js.map