"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeSearchCmd = void 0;
const os = __importStar(require("os"));
const output_formatting_1 = require("./output-formatting");
const result_codes_1 = require("./result-codes");
const error_logging_1 = require("./error-logging");
/**
 * Makes a {@link SearchCmd} function.
 */
function makeSearchCmd(parseEnv, searchPackages, log, debugLog) {
    return async (keyword, options) => {
        // parse env
        const envResult = await parseEnv(options);
        if (envResult.isErr()) {
            (0, error_logging_1.notifyEnvParsingFailed)(log, envResult.error);
            return result_codes_1.ResultCodes.Error;
        }
        const env = envResult.value;
        let usedEndpoint = "npmsearch";
        const searchResult = await searchPackages(env.registry, keyword, () => {
            usedEndpoint = "endpoint.all";
            log.warn("", "fast search endpoint is not available, using old search.");
        }).promise;
        if (searchResult.isErr()) {
            log.warn("", "/-/all endpoint is not available");
            return result_codes_1.ResultCodes.Error;
        }
        const results = searchResult.value;
        if (results.length === 0) {
            log.notice("", `No matches found for "${keyword}"`);
            return result_codes_1.ResultCodes.Ok;
        }
        debugLog(`${usedEndpoint}: ${results.map((it) => it.name).join(os.EOL)}`);
        console.log((0, output_formatting_1.formatAsTable)(results));
        return result_codes_1.ResultCodes.Ok;
    };
}
exports.makeSearchCmd = makeSearchCmd;
//# sourceMappingURL=cmd-search.js.map