"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EditorVersionNotSupportedError = exports.PackageWithVersionError = exports.PackumentNotFoundError = void 0;
const ts_custom_error_1 = require("ts-custom-error");
/**
 * Error for when the packument was not found.
 */
class PackumentNotFoundError extends ts_custom_error_1.CustomError {
    packageName;
    // noinspection JSUnusedLocalSymbols
    _class = "PackumentNotFoundError";
    constructor(
    /**
     * The name of the missing package.
     */
    packageName) {
        super("A packument was not found.");
        this.packageName = packageName;
    }
}
exports.PackumentNotFoundError = PackumentNotFoundError;
/**
 * Error for when a function expected a package-reference with only a name
 * e.g. "com.my-package", but it also included a version e.g.
 * "com.my-package@1.2.3".
 */
class PackageWithVersionError extends ts_custom_error_1.CustomError {
    // noinspection JSUnusedLocalSymbols
    _class = "PackageWithVersionError";
    constructor() {
        super("A package-reference including a version was specified when only a name was expected.");
    }
}
exports.PackageWithVersionError = PackageWithVersionError;
/**
 * Error for when OpenUPM was used with an editor-version that is not supported.
 */
class EditorVersionNotSupportedError extends ts_custom_error_1.CustomError {
    version;
    _class = "EditorVersionNotSupportedError";
    constructor(
    /**
     * The unsupported version.
     */
    version) {
        super();
        this.version = version;
    }
}
exports.EditorVersionNotSupportedError = EditorVersionNotSupportedError;
//# sourceMappingURL=common-errors.js.map