"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileParseError = exports.RegistryAuthenticationError = exports.GenericNetworkError = exports.FileMissingError = exports.GenericIOError = void 0;
const ts_custom_error_1 = require("ts-custom-error");
/**
 * Generic error for when some non-specific IO operation failed.
 */
class GenericIOError extends ts_custom_error_1.CustomError {
    operationType;
    // noinspection JSUnusedLocalSymbols
    _class = "GenericIOError";
    constructor(
    /**
     * The type of operation that failed. Either a read or write operation.
     */
    operationType) {
        super();
        this.operationType = operationType;
    }
}
exports.GenericIOError = GenericIOError;
/**
 * Error for when a required file or directory is missing.
 */
class FileMissingError extends ts_custom_error_1.CustomError {
    fileName;
    path;
    // noinspection JSUnusedLocalSymbols
    _class = "FileMissingError";
    constructor(
    /**
     * Name of the file. This is a constant string that can be used in
     * ifs and switches to identify the file that was missing.
     */
    fileName, 
    /**
     * The path where the file was searched but not found.
     */
    path) {
        super();
        this.fileName = fileName;
        this.path = path;
    }
}
exports.FileMissingError = FileMissingError;
/**
 * Generic error for when some non-specific network operation failed.
 */
class GenericNetworkError extends ts_custom_error_1.CustomError {
    _class = "GenericNetworkError";
}
exports.GenericNetworkError = GenericNetworkError;
/**
 * Error for when authentication with a registry failed.
 */
class RegistryAuthenticationError extends ts_custom_error_1.CustomError {
    _class = "RegistryAuthenticationError";
    constructor() {
        super();
    }
}
exports.RegistryAuthenticationError = RegistryAuthenticationError;
/**
 * Error for when a file could not be parsed into a specific target type.
 */
class FileParseError extends ts_custom_error_1.CustomError {
    filePath;
    targetDescription;
    // noinspection JSUnusedLocalSymbols
    _class = "FileParseError";
    constructor(
    /**
     * The path to the file that could not be parsed.
     */
    filePath, 
    /**
     * A description or name of the thing that the file was supposed to be
     * parsed to. This should be a constant string that can be used in ifs
     * and switches.
     */
    targetDescription) {
        super("A file could not be parsed into a specific target type.");
        this.filePath = filePath;
        this.targetDescription = targetDescription;
    }
}
exports.FileParseError = FileParseError;
//# sourceMappingURL=common-errors.js.map