"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeNpmLoginService = void 0;
const ts_results_es_1 = require("ts-results-es");
const common_errors_1 = require("../io/common-errors");
/**
 * Makes a new {@link NpmLoginService} function.
 */
function makeNpmLoginService(registryClient, debugLog) {
    return (registryUrl, username, email, password) => {
        return new ts_results_es_1.AsyncResult(new Promise((resolve) => {
            registryClient.adduser(registryUrl, { auth: { username, email, password } }, (error, responseData, _, response) => {
                if (response !== undefined && !responseData.ok) {
                    debugLog("A http request failed.", response);
                    resolve((0, ts_results_es_1.Err)(response.statusCode === 401
                        ? new common_errors_1.RegistryAuthenticationError()
                        : new common_errors_1.GenericNetworkError()));
                }
                else if (responseData.ok)
                    resolve((0, ts_results_es_1.Ok)(responseData.token));
                // TODO: Handle error
            });
        }));
    };
}
exports.makeNpmLoginService = makeNpmLoginService;
//# sourceMappingURL=npm-login.js.map