"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makePackageRemover = void 0;
const ts_results_es_1 = require("ts-results-es");
const project_manifest_1 = require("../domain/project-manifest");
const common_errors_1 = require("../common-errors");
function makePackageRemover(loadProjectManifest, writeProjectManifest) {
    const tryRemoveSingle = function (manifest, packageName) {
        // not found array
        const versionInManifest = manifest.dependencies[packageName];
        if (versionInManifest === undefined) {
            return (0, ts_results_es_1.Err)(new common_errors_1.PackumentNotFoundError(packageName));
        }
        manifest = (0, project_manifest_1.removeDependency)(manifest, packageName);
        manifest = {
            ...manifest,
            scopedRegistries: manifest.scopedRegistries
                // Remove package scope from all scoped registries
                ?.map((scopedRegistry) => ({
                ...scopedRegistry,
                scopes: scopedRegistry.scopes.filter((scope) => scope !== packageName),
            })),
        };
        return (0, ts_results_es_1.Ok)([manifest, { name: packageName, version: versionInManifest }]);
    };
    function tryRemoveAll(manifest, packageNames) {
        if (packageNames.length == 0)
            return (0, ts_results_es_1.Ok)([manifest, []]);
        const currentPackageName = packageNames[0];
        const remainingPackageNames = packageNames.slice(1);
        return tryRemoveSingle(manifest, currentPackageName).andThen(([updatedManifest, removedPackage]) => tryRemoveAll(updatedManifest, remainingPackageNames).map(([finalManifest, removedPackages]) => [
            finalManifest,
            [removedPackage, ...removedPackages],
        ]));
    }
    return (projectPath, packageNames) => {
        // load manifest
        const initialManifest = loadProjectManifest(projectPath);
        // remove
        const removeResult = initialManifest.andThen((it) => tryRemoveAll(it, packageNames));
        return removeResult.andThen(([updatedManifest, removedPackages]) => writeProjectManifest(projectPath, updatedManifest).map(() => removedPackages));
    };
}
exports.makePackageRemover = makePackageRemover;
//# sourceMappingURL=remove-packages.js.map